@@ -1,9 +1,8 @@
 use strict;
 use v5.10.0;
-use FusqlFS::Interface;
 
 package FusqlFS::Backend::PgSQL::Functions;
-use base 'FusqlFS::Interface';
+use parent 'FusqlFS::Artifact';
 
 1;
 
